"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
function syncTransform(fn) {
    return (data, enc, next) => {
        try {
            fn(data);
            next();
        }
        catch (err) {
            next(err);
        }
    };
}
exports.syncTransform = syncTransform;
function filter(predicate) {
    const transf = new stream_1.Transform({
        objectMode: true,
    });
    transf._transform = exports.syncTransform((chunk) => {
        if (predicate(chunk)) {
            transf.push(chunk);
        }
    });
    return transf;
}
exports.filter = filter;
function promiseMap(fn) {
    const transf = new stream_1.Transform({
        objectMode: true,
    });
    transf._transform = (chunk, encoding, next) => {
        fn(chunk)
            .then((res) => {
            transf.push(res);
            next();
        })
            .catch((err) => {
            transf.emit("error", err);
        });
    };
    return transf;
}
exports.promiseMap = promiseMap;
function map(fn) {
    const transf = new stream_1.Transform({
        objectMode: true,
    });
    transf._transform = exports.syncTransform((chunk) => {
        transf.push(fn(chunk));
    });
    return transf;
}
exports.map = map;
function buffer(bufferSize) {
    let buff = [];
    const transf = new stream_1.Transform({
        objectMode: true,
    });
    transf._transform = exports.syncTransform((chunk) => {
        if (buff.length >= bufferSize) {
            transf.push(buff);
            buff = [];
        }
        buff.push(chunk);
    });
    transf._flush = (done) => {
        transf.push(buff);
        done();
    };
    return transf;
}
exports.buffer = buffer;
function flatten() {
    const transf = new stream_1.Transform({
        objectMode: true,
    });
    transf._transform = exports.syncTransform((chunk) => {
        chunk.forEach((c) => {
            transf.push(c);
        });
    });
    return transf;
}
exports.flatten = flatten;
