"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const stream_1 = require("stream");
const _1 = require(".");
describe("stream util", () => {
    it("should filter", (done) => {
        const readable = new stream_1.Readable({ objectMode: true });
        const source = [1, 2, 3, 4];
        const res = [];
        readable
            .pipe(_1.filter((item) => item % 2 === 0))
            .on("data", (data) => res.push(data))
            .on("finish", () => {
            try {
                chai_1.expect(res).to.eql([2, 4]);
                done();
            }
            catch (err) {
                done(err);
            }
        })
            .on("error", done);
        source.map((item) => readable.push(item));
        readable.push(null);
    });
    it("should map", (done) => {
        const readable = new stream_1.Readable({ objectMode: true });
        const source = [2, 4, 8, 16];
        const res = [];
        readable
            .pipe(_1.map((i) => i + 1))
            .on("data", (data) => res.push(data))
            .on("finish", () => {
            try {
                chai_1.expect(res).to.eql([3, 5, 9, 17]);
                done();
            }
            catch (err) {
                done(err);
            }
        })
            .on("error", done);
        source.map((i) => readable.push(i));
        readable.push(null);
    });
    it("should buffer", (done) => {
        const readable = new stream_1.Readable({ objectMode: true });
        const source = [2, 4, 8, 16];
        const res = [];
        readable
            .pipe(_1.buffer(2))
            .on("data", (data) => res.push(data))
            .on("finish", () => {
            try {
                chai_1.expect(res).to.eql([[2, 4], [8, 16]]);
                done();
            }
            catch (err) {
                done(err);
            }
        })
            .on("error", done);
        source.map((i) => readable.push(i));
        readable.push(null);
    });
    it("should flatten", (done) => {
        const readable = new stream_1.Readable({ objectMode: true });
        const source = [[2, 4], [8, 16]];
        const res = [];
        readable
            .pipe(_1.flatten())
            .on("data", (data) => res.push(data))
            .on("finish", () => {
            try {
                chai_1.expect(res).to.eql([2, 4, 8, 16]);
                done();
            }
            catch (err) {
                done(err);
            }
        })
            .on("error", done);
        source.map((i) => readable.push(i));
        readable.push(null);
    });
});
describe("stream promise util", () => {
    it("should map stream promises", (done) => {
        const readable = new stream_1.Readable({ objectMode: true });
        const source = [
            Promise.resolve(1),
            Promise.resolve(2),
            Promise.resolve(3),
            Promise.resolve(4),
        ];
        const res = [];
        readable
            .pipe(_1.promiseMap((n) => new Promise((resolve, reject) => {
            n.then(resolve).catch(reject);
        })))
            .on("data", (data) => res.push(data))
            .on("finish", () => {
            try {
                chai_1.expect(res).to.eql([1, 2, 3, 4]);
                done();
            }
            catch (err) {
                done(err);
            }
        })
            .on("error", done);
        source.map((item) => readable.push(item));
        readable.push(null);
    });
});
